@@ -1,10 +1,10 @@
-;;; doric-light-theme.el --- Minimalist light theme -*- lexical-binding:t -*-
+;;; doric-light-theme.el --- Minimalist theme with light background and cool hues -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2025  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
-;; URL: https://github.com/protesilaos/ef-themes
+;; URL: https://github.com/protesilaos/doric-themes
 ;; Keywords: faces, theme, accessibility
 
 ;; This file is NOT part of GNU Emacs.
@@ -66,15 +66,15 @@
       (fg-magenta "#700d50")
       (fg-cyan "#005355")
 
-      (bg-red "#eac0bf")
-      (bg-green "#c0e2c4")
+      (bg-red "#f0c4c4")
+      (bg-green "#c0e8c2")
       (bg-yellow "#f0f0b0")
       (bg-blue "#c4cfe8")
       (bg-magenta "#eec2e6")
       (bg-cyan "#c1ebe4"))
   "Palette of `doric-light' theme.")
 
-  (doric-themes-define-theme doric-light light))
+  (doric-themes-define-theme doric-light light "Minimalist theme with light background and cool hues"))
 
 (provide 'doric-light-theme)
 ;;; doric-light-theme.el ends here
